@@ -80,18 +80,14 @@ class TaskWrapper():
         # info = subprocess.STARTUPINFO()
         # info.dwFlags = subprocess.STARTUPINFO()
         # info.wShowWindow = SW_MINIMIZE
-        p = subprocess.Popen(['python3', filepath], cwd=self.cwd) #, startupinfo=info)
-        stdout, stderr = p.communicate()
-        log_time = datetime.strftime(datetime.now(), '%Y%m%d-%hh%mm%ss')
-        log_file_stdout = os.path.join(self.log_dir, log_time, "stdout.txt")
-        log_file_stderr = os.path.join(self.log_dir, log_time, "stdout.txt")
+
+        log_time = datetime.strftime(datetime.now(), '%Y%m%d-%H%M%S')
+        log_file_stdout = os.path.join(self.log_dir, log_time+"stdout.txt")
+        log_file_stderr = os.path.join(self.log_dir, log_time+"stdout.txt")
+        
+        with open(log_file_stdout, "w+") as stdout_log_file, open(log_file_stderr, "w+") as stderr_log_file:
+            p = subprocess.Popen(['python3', filepath], cwd=self.cwd, stdout=stdout_log_file, stderr=stderr_log_file) #, startupinfo=info)
         
-        with open(log_file_stdout, "w") as log_file:
-            log_file.write(stdout)
-
-        with open(log_file_stderr, "w") as log_file:
-            log_file.write(stderr)
-
         return p
 
     def init_log_dir(self):
